@@ -61,10 +61,10 @@ ac_table = {
         'hub new': ['--help', '--output-dir', '--template', '--type', '--overwrite'],
         'hub init': ['--help', '--output-dir', '--template', '--type', '--overwrite'],
         'hub create': ['--help', '--output-dir', '--template', '--type', '--overwrite'],
-        'hub build': ['--help', '--username', '--password', '--registry', '--pull', '--push', '--dry-run',
-                      '--prune-images', '--raise-error', '--test-uses', '--host-info', '--daemon'],
-        'hub push': ['--help', '--username', '--password', '--registry'],
-        'hub pull': ['--help', '--username', '--password', '--registry'],
+        'hub build': ['--help', '--username', '--password', '--registry', '--repository', '--pull', '--push',
+                      '--dry-run', '--prune-images', '--raise-error', '--test-uses', '--host-info', '--daemon'],
+        'hub push': ['--help', '--username', '--password', '--registry', '--repository'],
+        'hub pull': ['--help', '--username', '--password', '--registry', '--repository'],
         'hub list': ['--help', '--name', '--kind', '--keywords', '--type', '--local-only'],
         'hub': ['--help', 'login', 'new', 'init', 'create', 'build', 'push', 'pull', 'list'],
         'pea': ['--help', '--name', '--identity', '--uses', '--py-modules', '--uses-internal', '--entrypoint',
