@@ -2,7 +2,7 @@ __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
 import time
-from typing import Iterator, Callable, Union
+from typing import Iterator, Callable, Union, Tuple
 
 from . import request
 from .grpc import GrpcClient
@@ -56,7 +56,7 @@ class PyClient(GrpcClient):
         return self._mode
 
     @mode.setter
-    def mode(self, value: ClientMode):
+    def mode(self, value: ClientMode) -> None:
         if isinstance(value, ClientMode):
             self._mode = value
             self.args.mode = value
@@ -64,7 +64,7 @@ class PyClient(GrpcClient):
             raise ValueError(f'{value} must be one of {ClientMode}')
 
     @staticmethod
-    def check_input(input_fn: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable] = None):
+    def check_input(input_fn: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable] = None) -> None:
         """Validate the input_fn and print the first request if success
 
         :param input_fn: the input function
@@ -117,7 +117,6 @@ class PyClient(GrpcClient):
             tname = str(kwargs['mode']).lower()
 
         req_iter = getattr(request, tname)(**_kwargs)
-        # next(req_iter)
 
         with ProgressBar(task_name=tname) as p_bar, TimeContext(tname):
             for resp in self._stub.Call(req_iter):
@@ -145,7 +144,7 @@ class PyClient(GrpcClient):
             raise BadClient('input_fn is empty or not set')
 
     @input_fn.setter
-    def input_fn(self, bytes_gen: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable]):
+    def input_fn(self, bytes_gen: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable]) -> None:
         if self._input_fn:
             self.logger.warning('input_fn is not empty, overrided')
         if hasattr(bytes_gen, '__call__'):
@@ -187,24 +186,24 @@ class PyClient(GrpcClient):
 
         return False
 
-    def train(self, input_fn: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable] = None,
-              output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs):
+    def train(self, input_fn: Union[Iterator[Union['jina_pb2.Document', bytes]], Callable] = None,
+              output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs) -> None:
         self.mode = ClientMode.TRAIN
         self.input_fn = input_fn
         if not self.args.skip_dry_run:
             self.dry_run(as_request='train')
         self.start(output_fn, **kwargs)
 
-    def search(self, input_fn: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable] = None,
-               output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs):
+    def search(self, input_fn: Union[Iterator[Union['jina_pb2.Document', bytes]], Callable] = None,
+               output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs) -> None:
         self.mode = ClientMode.SEARCH
         self.input_fn = input_fn
         if not self.args.skip_dry_run:
             self.dry_run(as_request='search')
         self.start(output_fn, **kwargs)
 
-    def index(self, input_fn: Union[Iterator['jina_pb2.Document'], Iterator[bytes], Callable] = None,
-              output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs):
+    def index(self, input_fn: Union[Iterator[Union['jina_pb2.Document', bytes]], Callable]= None,
+              output_fn: Callable[['jina_pb2.Message'], None] = None, **kwargs) -> None:
         self.mode = ClientMode.INDEX
         self.input_fn = input_fn
         if not self.args.skip_dry_run:
