@@ -26,7 +26,9 @@ def store_init_kwargs(func: Callable) -> Callable:
     @wraps(func)
     def arg_wrapper(self, *args, **kwargs):
         if func.__name__ != '__init__':
-            raise TypeError('this decorator should only be used on __init__ method of a driver')
+            raise TypeError(
+                'this decorator should only be used on __init__ method of a driver'
+            )
         taboo = {'self', 'args', 'kwargs'}
         all_pars = inspect.signature(func).parameters
         tmp = {k: v.default for k, v in all_pars.items() if k not in taboo}
@@ -82,8 +84,12 @@ class QuerySetReader:
     def _get_parameter(self, key: str, default: Any):
         if getattr(self, 'queryset', None):
             for q in self.queryset:
-                if (not q.disabled and self.__class__.__name__ == q.name and
-                        q.priority > self._priority and key in q.parameters):
+                if (
+                    not q.disabled
+                    and self.__class__.__name__ == q.name
+                    and q.priority > self._priority
+                    and key in q.parameters
+                ):
                     ret = q.parameters[key]
                     return dict(ret) if isinstance(ret, Struct) else ret
         return getattr(self, f'_{key}', default)
@@ -99,7 +105,6 @@ class QuerySetReader:
 
 
 class DriverType(type):
-
     def __new__(cls, *args, **kwargs):
         _cls = super().__new__(cls, *args, **kwargs)
         return cls.register_class(_cls)
@@ -199,7 +204,8 @@ class BaseDriver(metaclass=DriverType):
     @classmethod
     def _get_instance_from_yaml(cls, constructor, node):
         data = ruamel.yaml.constructor.SafeConstructor.construct_mapping(
-            constructor, node, deep=True)
+            constructor, node, deep=True
+        )
 
         obj = cls(**data.get('with', {}))
         return obj
@@ -209,7 +215,7 @@ class BaseDriver(metaclass=DriverType):
 
     def __getstate__(self) -> Dict[str, Any]:
         """Do not save the BasePea, as it would be cross-referencing. In other words, a deserialized :class:`BaseDriver` from
-        file is always unattached. """
+        file is always unattached."""
         d = dict(self.__dict__)
         if 'pea' in d:
             del d['pea']
@@ -218,7 +224,6 @@ class BaseDriver(metaclass=DriverType):
 
 
 class BaseRecursiveDriver(BaseDriver):
-
     def __init__(self, traversal_paths: Tuple[str] = ('c', 'r'), *args, **kwargs):
         """
         :param traversal_paths: The describes the leaves of the document tree on which _apply_all are called
@@ -227,14 +232,14 @@ class BaseRecursiveDriver(BaseDriver):
         self._traversal_paths = [path.lower() for path in traversal_paths]
 
     def _apply_all(
-            self,
-            docs: Iterable['jina_pb2.Document'],
-            context_doc: 'jina_pb2.Document',
-            field: str,
-            *args,
-            **kwargs
+        self,
+        docs: Iterable['jina_pb2.Document'],
+        context_doc: 'jina_pb2.Document',
+        field: str,
+        *args,
+        **kwargs,
     ) -> None:
-        """ Apply function works on a list of docs, modify the docs in-place
+        """Apply function works on a list of docs, modify the docs in-place
 
         :param docs: a list of :class:`jina_pb2.Document` objects to work on; they could come from ``matches``/``chunks``.
         :param context_doc: the owner of ``docs``
@@ -244,36 +249,51 @@ class BaseRecursiveDriver(BaseDriver):
     def __call__(self, *args, **kwargs):
         self._traverse_apply(self.req.docs, *args, **kwargs)
 
-    def _traverse_apply(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs) -> None:
+    def _traverse_apply(
+        self, docs: Iterable['jina_pb2.Document'], *args, **kwargs
+    ) -> None:
         for path in self._traversal_paths:
             if path[0] == 'r':
                 self._traverse_rec(docs, None, None, [], *args, **kwargs)
             for doc in docs:
-                self._traverse_rec([doc, ], None, None, path, *args, **kwargs)
+                self._traverse_rec(
+                    [
+                        doc,
+                    ],
+                    None,
+                    None,
+                    path,
+                    *args,
+                    **kwargs,
+                )
 
     def _traverse_rec(self, docs, parent_doc, parent_edge_type, path, *args, **kwargs):
         if path:
             next_edge = path[0]
             for doc in docs:
                 if next_edge == 'm':
-                    self._traverse_rec(doc.matches, doc, 'matches', path[1:], *args, **kwargs)
+                    self._traverse_rec(
+                        doc.matches, doc, 'matches', path[1:], *args, **kwargs
+                    )
                 if next_edge == 'c':
-                    self._traverse_rec(doc.chunks, doc, 'chunks', path[1:], *args, **kwargs)
+                    self._traverse_rec(
+                        doc.chunks, doc, 'chunks', path[1:], *args, **kwargs
+                    )
         else:
             self._apply_all(docs, parent_doc, parent_edge_type, *args, **kwargs)
 
 
 class BaseExecutableDriver(BaseRecursiveDriver):
     """A :class:`BaseExecutableDriver` is an intermediate logic unit between the :class:`jina.peapods.pea.BasePea` and :class:`jina.executors.BaseExecutor`
-        It reads the protobuf message, extracts/modifies the required information and then sends to the :class:`jina.executors.BaseExecutor`,
-        finally it returns the message back to :class:`jina.peapods.pea.BasePea`.
+    It reads the protobuf message, extracts/modifies the required information and then sends to the :class:`jina.executors.BaseExecutor`,
+    finally it returns the message back to :class:`jina.peapods.pea.BasePea`.
 
-        A :class:`BaseExecutableDriver` needs to be :attr:`attached` to a :class:`jina.peapods.pea.BasePea` and :class:`jina.executors.BaseExecutor` before using.
-        This is done by :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
+    A :class:`BaseExecutableDriver` needs to be :attr:`attached` to a :class:`jina.peapods.pea.BasePea` and :class:`jina.executors.BaseExecutor` before using.
+    This is done by :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
     """
 
     def __init__(self, executor: str = None, method: str = None, *args, **kwargs):
-        """ Initialize a :class:`BaseExecutableDriver`
+        """Initialize a :class:`BaseExecutableDriver`
 
         :param executor: the name of the sub-executor, only necessary when :class:`jina.executors.compound.CompoundExecutor` is used
         :param method: the function name of the executor that the driver feeds to
@@ -292,7 +312,10 @@ class BaseExecutableDriver(BaseRecursiveDriver):
     @property
     def exec_fn(self) -> Callable:
         """the function of :func:`jina.executors.BaseExecutor` to call """
-        if self.envelope.status.code != jina_pb2.Status.ERROR or self.pea.args.skip_on_error < OnErrorSkip.EXECUTOR:
+        if (
+            self.envelope.status.code != jina_pb2.Status.ERROR
+            or self.pea.args.skip_on_error < OnErrorSkip.EXECUTOR
+        ):
             return self._exec_fn
         else:
             return lambda *args, **kwargs: None
@@ -305,12 +328,16 @@ class BaseExecutableDriver(BaseRecursiveDriver):
                 self._exec = executor[self._executor_name]
             else:
                 for c in executor.components:
-                    if any(t.__name__ == self._executor_name for t in type.mro(c.__class__)):
+                    if any(
+                        t.__name__ == self._executor_name for t in type.mro(c.__class__)
+                    ):
                         self._exec = c
                         break
             if self._exec is None:
-                self.logger.critical(f'fail to attach the driver to {executor}, '
-                                     f'no executor is named or typed as {self._executor_name}')
+                self.logger.critical(
+                    f'fail to attach the driver to {executor}, '
+                    f'no executor is named or typed as {self._executor_name}'
+                )
         else:
             self._exec = executor
 
@@ -319,7 +346,7 @@ class BaseExecutableDriver(BaseRecursiveDriver):
 
     def __getstate__(self) -> Dict[str, Any]:
         """Do not save the executor and executor function, as it would be cross-referencing and unserializable.
-        In other words, a deserialized :class:`BaseExecutableDriver` from file is always unattached. """
+        In other words, a deserialized :class:`BaseExecutableDriver` from file is always unattached."""
         d = super().__getstate__()
         if '_exec' in d:
             del d['_exec']
