@@ -1,9 +1,5 @@
-__copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
-__license__ = "Apache-2.0"
-
 from functools import partial
-from collections.abc import Iterable
-from typing import Callable, List, Type, Union
+from typing import Callable, List, Type, Union, Iterable
 
 
 ## Exceptions
