@@ -1,7 +1,7 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from typing import Tuple
+from typing import Iterable, Tuple
 
 from .. import QuerySetReader, BaseRecursiveDriver
 
@@ -21,22 +21,21 @@ class ExcludeQL(QuerySetReader, BaseRecursiveDriver):
         ExcludeQL will avoid `buffer` and `chunks` fields to be sent to the next `Pod`
     """
 
-    def __init__(self, fields: Tuple, *args, **kwargs):
+    def __init__(self, fields: Tuple, traversal_paths: Tuple[str] = ('c',), *args, **kwargs):
         """
 
         :param fields: the pruned field names in tuple
         """
-        super().__init__(*args, **kwargs)
+        super().__init__(traversal_paths=traversal_paths, *args, **kwargs)
         if isinstance(fields, str):
             self._fields = {fields, }
         else:
             self._fields = set(fields)
 
-        self.is_apply_all = False
-
-    def _apply(self, doc: 'jina_pb2.Document', *args, **kwargs):
-        for k in self.fields:
-            doc.ClearField(k)
+    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs):
+        for doc in docs:
+            for k in self.fields:
+                doc.ClearField(k)
 
 
 class SelectQL(ExcludeQL):
@@ -51,10 +50,12 @@ class SelectQL(ExcludeQL):
 
         SelectQL will ensure that the `outgoing` documents only contain the field `matches`
     """
-    def _apply(self, doc: 'jina_pb2.Document', *args, **kwargs):
-        for k in doc.DESCRIPTOR.fields_by_name.keys():
-            if k not in self.fields:
-                doc.ClearField(k)
+
+    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs):
+        for doc in docs:
+            for k in doc.DESCRIPTOR.fields_by_name.keys():
+                if k not in self.fields:
+                    doc.ClearField(k)
 
 
 class ExcludeReqQL(ExcludeQL):
@@ -72,6 +73,7 @@ class SelectReqQL(ExcludeReqQL):
     """Clean up request from the request-level protobuf message to reduce the total size of the message, it works with the opposite
     logic as `:class:`ExcludeReqQL`
     """
+
     def __call__(self, *args, **kwargs):
         for k in self.msg.DESCRIPTOR.fields_by_name.keys():
             if k not in self.fields:
