@@ -112,9 +112,16 @@ class DockerLoginFailed(Exception):
     """ Exception to raise for docker hub login failures """
 
 
-class PretrainedModelFileDoesNotExist(Exception):
+class ModelCheckpointNotExist(Exception):
     """ Exception to raise for executors depending on pretrained model files when they do not exist """
 
 
+class PretrainedModelFileDoesNotExist(ModelCheckpointNotExist):
+    """ Depreciated, used in the hub executors
+
+    TODO: to be removed after hub executors uses ModelCheckpointNotExist
+    """
+
+
 class BadDocID(Exception):
     """ Exception when user give a non-hex string as the doc id """
