@@ -293,14 +293,21 @@ class Flow(ExitStack):
 
         needs = op_flow._parse_endpoints(op_flow, pod_name, needs, connect_to_last_pod=True)
 
-        kwargs.update(op_flow._common_kwargs)
+        for key, value in op_flow._common_kwargs.items():
+            if key not in kwargs:
+                kwargs[key] = value
+
         kwargs['name'] = pod_name
 
-        op_flow._pod_nodes[pod_name] = FlowPod(kwargs=kwargs, needs=needs, pod_role=pod_role)
+        op_flow._pod_nodes[pod_name] = self._invoke_flowpod(kwargs, needs, pod_role)
         op_flow.last_pod = pod_name
 
         return op_flow
 
+    def _invoke_flowpod(self, kwargs, needs, pod_role):
+        """This gets inherited in jinad"""
+        return FlowPod(kwargs=kwargs, needs=needs, pod_role=pod_role)
+
     def inspect(self, name: str = 'inspect', *args, **kwargs) -> 'Flow':
         """Add an inspection on the last changed Pod in the Flow
 
