@@ -58,7 +58,7 @@ def set_logger_parser(parser=None):
 def set_hub_base_parser(parser=None):
     if not parser:
         parser = set_base_parser()
-    parser.add_argument('--username', type=str, help='the registry username',
+    parser.add_argument('--username', type=str, help='the Docker registry username',
                         default=os.environ.get('JINAHUB_USERNAME', ''))
     # _gp = parser.add_mutually_exclusive_group()
     # _gp.add_argument('--password-stdin', type=argparse.FileType('r'),
@@ -67,8 +67,9 @@ def set_hub_base_parser(parser=None):
     parser.add_argument('--password', type=str, help='the plaintext password',
                         default=os.environ.get('JINAHUB_PASSWORD', ''))
     parser.add_argument('--registry', type=str, default='https://index.docker.io/v1/',
-                        help='the URL to the registry, e.g. https://index.docker.io/v1/')
-
+                        help='the URL to the Docker registry, e.g. https://index.docker.io/v1/')
+    parser.add_argument('--repository', type=str, default='jinahub',
+                        help='the Docker repository name, change this when pushing image to a personal repository')
     return parser
 
 
@@ -174,7 +175,7 @@ def set_hw_parser(parser=None):
                     default=resource_filename('jina', '/'.join(('resources', 'helloworld.flow.index.yml'))),
                     help='the yaml path of the index flow')
     gp.add_argument('--index-data-url', type=str,
-                    default='https://github.com/zalandoresearch/fashion-mnist/raw/master/data/fashion/train-images-idx3-ubyte.gz',
+                    default='http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/train-images-idx3-ubyte.gz',
                     help='the url of index data (should be in idx3-ubyte.gz format)')
     gp.add_argument('--index-batch-size', type=int,
                     default=1024,
@@ -184,7 +185,7 @@ def set_hw_parser(parser=None):
                     default=resource_filename('jina', '/'.join(('resources', 'helloworld.flow.query.yml'))),
                     help='the yaml path of the query flow')
     gp.add_argument('--query-data-url', type=str,
-                    default='https://github.com/zalandoresearch/fashion-mnist/raw/master/data/fashion/t10k-images-idx3-ubyte.gz',
+                    default='http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/t10k-images-idx3-ubyte.gz',
                     help='the url of query data (should be in idx3-ubyte.gz format)')
     gp.add_argument('--query-batch-size', type=int,
                     default=32,
