@@ -3,8 +3,9 @@ __license__ = "Apache-2.0"
 
 import argparse
 from typing import Dict, Union
+
 from .pea import BasePea
-from ..logging import get_logger
+from ..logging import JinaLogger
 
 
 class HeadPea(BasePea):
@@ -16,9 +17,9 @@ class HeadPea(BasePea):
             if self.args.name:
                 self.name = self.args.name
                 self.name = f'{self.name}-head'
-            self.logger = get_logger(self.name, **vars(self.args))
+            self.logger = JinaLogger(self.name, **vars(self.args))
         else:
-            self.logger = get_logger(self.name)
+            self.logger = JinaLogger(self.name)
 
     def __str__(self):
         return self.name
