@@ -3,8 +3,9 @@ __license__ = "Apache-2.0"
 
 import argparse
 from typing import Dict, Union
+
 from .pea import BasePea
-from ..logging import get_logger
+from ..logging import JinaLogger
 
 
 class TailPea(BasePea):
@@ -12,10 +13,13 @@ class TailPea(BasePea):
     def __init__(self, args: Union['argparse.Namespace', Dict]):
         super().__init__(args)
         self.name = self.__class__.__name__
-        if isinstance(args, argparse.Namespace):
-            if args.name:
-                self.name = args.name
+        if isinstance(self.args, argparse.Namespace):
+            if self.args.name:
+                self.name = self.args.name
                 self.name = f'{self.name}-tail'
-            self.logger = get_logger(self.name, **vars(args))
+            self.logger = JinaLogger(self.name, **vars(self.args))
         else:
-            self.logger = get_logger(self.name)
+            self.logger = JinaLogger(self.name)
+
+    def __str__(self):
+        return self.name
