@@ -741,82 +741,6 @@ def _check_msg_version(msg: 'jina_pb2.Message'):
                                 'the message is probably sent from a very outdated JINA version')
 
 
-def _extract_bytes_from_documents(docs: Iterable['jina_pb2.Document']) -> Tuple:
-    doc_bytes = []
-    chunk_bytes = []
-    chunk_byte_type = b''
-
-    # for train request
-    for d in docs:
-        doc_bytes.append(d.buffer)
-        d.ClearField('buffer')
-
-        for c in d.chunks:
-            # oneof content {
-            # string text = 2;
-            # NdArray blob = 3;
-            # bytes raw = 7;
-            # }
-            chunk_bytes.append(c.embedding.buffer)
-            c.embedding.ClearField('buffer')
-
-            ctype = c.WhichOneof('content') or ''
-            chunk_byte_type = ctype.encode()
-            if ctype == 'buffer':
-                chunk_bytes.append(c.buffer)
-                c.ClearField('buffer')
-            elif ctype == 'blob':
-                chunk_bytes.append(c.blob.buffer)
-                c.blob.ClearField('buffer')
-            elif ctype == 'text':
-                chunk_bytes.append(c.text.encode())
-                c.ClearField('text')
-
-    return doc_bytes, chunk_bytes, chunk_byte_type
-
-
-def _fill_buffer_to_documents(msg_data: List[bytes], docs: Iterable['jina_pb2.Document'], offset: int = 3):
-    """
-    Message comes split in different parts (that's why it comes as an Iterable, Each element
-            can be any sendable object (Frame, bytes, buffer-providers)):
-    Parts 0 and 1 contain information about potentially the receiver (if DEALER) and whether it is compressed or not.
-    Part 2 has a msg representation.
-    Part 3 (offset = 3) has the encoded name of the type of chunk bytes (Limitation: Only consider one chunk type for complete message)
-    Parts 4 and 5 contain the length of the doc_bytes and chunk_bytes respectively.
-    Then N number of Parts come with the doc bytes
-    Then M number of Parts com with the chunk bytes (chunk bytes length is twice the number of chunks in the message)
-    """
-    chunk_byte_type = msg_data[offset].decode()
-    doc_bytes_len = int(msg_data[offset + 1])
-    chunk_bytes_len = int(msg_data[offset + 2])
-    doc_bytes = msg_data[(offset + 3):(offset + 3 + doc_bytes_len)]
-    chunk_bytes = msg_data[(offset + 3 + doc_bytes_len):]
-
-    if len(chunk_bytes) != chunk_bytes_len:
-        raise ValueError('"chunk_bytes_len"=%d in message, but the actual length is %d' % (
-            chunk_bytes_len, len(chunk_bytes)))
-
-    c_idx = 0
-    d_idx = 0
-    for d in docs:
-        if doc_bytes and doc_bytes[d_idx]:
-            d.buffer = doc_bytes[d_idx]
-            d_idx += 1
-
-        for c in d.chunks:
-            if chunk_bytes and chunk_bytes[c_idx]:
-                c.embedding.buffer = chunk_bytes[c_idx]
-            c_idx += 1
-
-            if chunk_byte_type == 'buffer':
-                c.buffer = chunk_bytes[c_idx]
-                c_idx += 1
-            elif chunk_byte_type == 'blob':
-                c.blob.buffer = chunk_bytes[c_idx]
-                c_idx += 1
-            elif chunk_byte_type == 'text':
-                c.text = chunk_bytes[c_idx].decode()
-                c_idx += 1
 
 
 def _add_route(evlp, pod_name, identity):
